# Please keep this package sync with FC

%global _python_bytecompile_extra %nil

# Components enabled if supported by target architecture:
%define gold_arches %{ix86} x86_64 %{arm} aarch64 %{power64} s390x
%ifarch %{gold_arches}
  %bcond_without gold
%else
  %bcond_with gold
%endif

%bcond_with compat_build

%global llvm_libdir %{_libdir}/%{name}
%global build_llvm_libdir %{buildroot}%{llvm_libdir}
#%%global rc_ver 2
%global baserelease 4
%global llvm_srcdir llvm-%{version}%{?rc_ver:rc%{rc_ver}}.src
%global maj_ver 11
%global min_ver 0
%global patch_ver 1

%ifarch %ix86 x86_64
# ARM/AARCH64 enabled due to rhbz#1627500
%global llvm_targets X86;AMDGPU;NVPTX;BPF;ARM;AArch64
%endif
%ifarch aarch64
%global llvm_targets AArch64;AMDGPU;BPF
%endif
%ifarch %{arm}
%global llvm_targets ARM;AMDGPU;BPF
%endif

%if %{with compat_build}
%global pkg_name llvm%{maj_ver}.%{min_ver}
%global exec_suffix -%{maj_ver}.%{min_ver}
%global install_prefix %{_libdir}/%{name}
%global install_bindir %{install_prefix}/bin
%global install_includedir %{install_prefix}/include
%global install_libdir %{install_prefix}/lib

%global pkg_bindir %{install_bindir}
%global pkg_includedir %{_includedir}/%{name}
%global pkg_libdir %{install_libdir}
%else
%global pkg_name llvm
%global install_prefix /usr
%global install_libdir %{_libdir}
%global pkg_libdir %{install_libdir}
%endif

%define major %maj_ver.%min_ver
%define libname %mklibname %name %major
%define libname_devel %mklibname -d %name

%global build_install_prefix %{buildroot}%{install_prefix}

Name:		%{pkg_name}
Version:	%{maj_ver}.%{min_ver}.%{patch_ver}
Release:	%mkrel %{baserelease}%{?rc_ver:.rc%{rc_ver}}.2
Summary:	The Low Level Virtual Machine

License:	NCSA
Group:		Development/Other
URL:		http://llvm.org
Source0:	https://github.com/llvm/llvm-project/releases/download/llvmorg-%{version}%{?rc_ver:-rc%{rc_ver}}/%{llvm_srcdir}.tar.xz
Source1:	https://github.com/llvm/llvm-project/releases/download/llvmorg-%{version}%{?rc_ver:-rc%{rc_ver}}/%{llvm_srcdir}.tar.xz.sig
Source2:	tstellar-gpg-key.asc

%if %{without compat_build}
Source3:	run-lit-tests
Source4:	lit.fedora.cfg.py
%endif

# Fedora Patches
# Fix coreos-installer test crash on s390x (rhbz#1883457), https://reviews.llvm.org/D89034
Patch1:		0001-SystemZ-Use-LA-instead-of-AGR-in-eliminateFrameIndex.patch

Patch2:         0001-gcc11.patch

BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:	cmake
BuildRequires:	ninja-build
BuildRequires:	zlib-devel
BuildRequires:	pkgconfig(libffi) >= 3.2
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	python3-sphinx
BuildRequires:	python3-recommonmark
%if %{with gold}
BuildRequires:	binutils-devel
%endif
%ifarch %{valgrind_arches}
# Enable extra functionality when run the LLVM JIT under valgrind.
BuildRequires:  valgrind-devel
%endif
# LLVM's LineEditor library will use libedit if it is available.
BuildRequires:  libedit-devel
# We need python3-devel for pathfix.py.
BuildRequires:	python3-devel

# For origin certification
BuildRequires:	gnupg2

Requires:	%libname = %version-%release

Provides:	llvm(major) = %{maj_ver}

%description
LLVM is a compiler infrastructure designed for compile-time, link-time,
runtime, and idle-time optimization of programs from arbitrary programming
languages. The compiler infrastructure includes mirror sets of programming
tools as well as libraries with equivalent functionality.

%package -n %{libname_devel}
Summary:	Development files for LLVM
Group:		Development/Other
Provides:	llvm-devel = %version-%release
Provides:	llvm-devel%{?_isa} = %version-%release
Requires:	%libname = %version-%release
Requires:	%name = %version-%release
# The installed LLVM cmake files will add -ledit to the linker flags for any
# app that requires the libLLVMLineEditor, so we need to make sure
# libedit-devel is available.
Requires:	libedit-devel
# The installed cmake files reference binaries from llvm-test and llvm-static.
# We tried in the past to split the cmake exports for these binaries out into
# separate files, so that llvm-devel would not need to Require these packages,
# but this caused bugs (rhbz#1773678) and forced us to carry two non-upstream
# patches.
Requires:	llvm-static%{?_isa} = %{version}-%{release}
Requires:	llvm-test%{?_isa} = %{version}-%{release}



Provides:	llvm-devel(major) = %{maj_ver}

%description -n %{libname_devel}
This package contains library and header files needed to develop new native
programs that use the LLVM infrastructure.

%package doc
Summary:	Documentation for LLVM
Group:		Documentation
BuildArch:	noarch
Requires:	%{name} = %{version}-%{release}

%description doc
Documentation for the LLVM compiler infrastructure.

%package -n %libname
Summary:	LLVM shared libraries
Group:		System/Libraries
# (tmb) filter out devel provides/requires that gets added because of this symlink
# It's because of the symlink. See eg:
# echo /usr/lib64/libLLVM-10.0.0.so|/usr/lib/rpm/rpmdeps -R|grep dev
%global __provides_exclude_from ^%{_libdir}/libLLVM-%{version}\\.so$|libLTO.so$|LLVMgold.so$|libRemarks.so$
%global __requires_exclude_from ^%{_libdir}/libLLVM-%{version}\\.so$|libLTO.so$|LLVMgold.so$|libRemarks.so$

%description -n %libname
Shared libraries for the LLVM compiler infrastructure.

%package static
Summary:	LLVM static libraries
Group:		Development/Other
Conflicts:	%{name}-devel < 8

%description static
Static libraries for the LLVM compiler infrastructure.

%if %{without compat_build}

%package test
Summary:	LLVM regression tests
Requires:	%{name}%{?_isa} = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}
Requires:	python3-lit
# The regression tests need gold.
Requires:	binutils
# This is for llvm-config
Requires:	%{name}-devel%{?_isa} = %{version}-%{release}
# Bugpoint tests require gcc
Requires:	gcc
Requires:	findutils

Provides:	llvm-test(major) = %{maj_ver}

%description test
LLVM regression tests.

%package googletest
Summary: LLVM's modified googletest sources

%description googletest
LLVM's modified googletest sources.

%endif

%prep
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%autosetup -n %{llvm_srcdir} -p2

pathfix.py -i %{__python3} -pn \
	test/BugPoint/compile-custom.ll.py \
	tools/opt-viewer/*.py \
	utils/update_cc_test_checks.py

%build
# FC compatibility:
%global _vpath_builddir _build

%ifarch s390 %{arm} %ix86
# Decrease debuginfo verbosity to reduce memory consumption during final library linking
%global optflags %(echo %{optflags} | sed 's/-g /-g1 /')
%endif

# force off shared libs as cmake macros turns it on.
%cmake -G Ninja \
	-DBUILD_SHARED_LIBS:BOOL=OFF \
	-DLLVM_PARALLEL_LINK_JOBS=1 \
	-DCMAKE_BUILD_TYPE=RelWithDebInfo \
	-DCMAKE_SKIP_RPATH:BOOL=ON \
%ifarch s390 %{arm} %ix86
	-DCMAKE_C_FLAGS_RELWITHDEBINFO="%{optflags} -DNDEBUG" \
	-DCMAKE_CXX_FLAGS_RELWITHDEBINFO="%{optflags} -DNDEBUG" \
%endif
%if %{without compat_build}
%if 0%{?__isa_bits} == 64
	-DLLVM_LIBDIR_SUFFIX=64 \
%else
	-DLLVM_LIBDIR_SUFFIX= \
%endif
%endif
	\
	-DLLVM_TARGETS_TO_BUILD="%{llvm_targets}" \
	-DLLVM_ENABLE_LIBCXX:BOOL=OFF \
	-DLLVM_ENABLE_ZLIB:BOOL=ON \
	-DLLVM_ENABLE_FFI:BOOL=ON \
	-DLLVM_ENABLE_RTTI:BOOL=ON \
%if %{with gold}
	-DLLVM_BINUTILS_INCDIR=%{_includedir} \
%endif
	-DLLVM_EXPERIMENTAL_TARGETS_TO_BUILD=AVR \
	\
	-DLLVM_BUILD_RUNTIME:BOOL=ON \
	\
	-DLLVM_INCLUDE_TOOLS:BOOL=ON \
	-DLLVM_BUILD_TOOLS:BOOL=ON \
	\
	-DLLVM_INCLUDE_TESTS:BOOL=ON \
	-DLLVM_BUILD_TESTS:BOOL=ON \
	\
	-DLLVM_INCLUDE_EXAMPLES:BOOL=ON \
	-DLLVM_BUILD_EXAMPLES:BOOL=OFF \
	\
	-DLLVM_INCLUDE_UTILS:BOOL=ON \
%if %{with compat_build}
	-DLLVM_INSTALL_UTILS:BOOL=OFF \
%else
	-DLLVM_INSTALL_UTILS:BOOL=ON \
	-DLLVM_UTILS_INSTALL_DIR:PATH=%{_bindir} \
	-DLLVM_TOOLS_INSTALL_DIR:PATH=bin \
%endif
	\
	-DLLVM_INCLUDE_DOCS:BOOL=ON \
	-DLLVM_BUILD_DOCS:BOOL=ON \
	-DLLVM_ENABLE_SPHINX:BOOL=ON \
	-DLLVM_ENABLE_DOXYGEN:BOOL=OFF \
	\
%if %{without compat_build}
	-DLLVM_VERSION_SUFFIX='' \
%endif
	-DLLVM_BUILD_LLVM_DYLIB:BOOL=ON \
	-DLLVM_DYLIB_EXPORT_ALL:BOOL=ON \
	-DLLVM_LINK_LLVM_DYLIB:BOOL=ON \
	-DLLVM_BUILD_EXTERNAL_COMPILER_RT:BOOL=ON \
	-DLLVM_INSTALL_TOOLCHAIN_ONLY:BOOL=OFF \
	\
	-DSPHINX_WARNINGS_AS_ERRORS=OFF \
	-DCMAKE_INSTALL_PREFIX=%{install_prefix} \
	-DLLVM_INSTALL_SPHINX_HTML_DIR=%{_pkgdocdir}/html \
	-DSPHINX_EXECUTABLE=%{_bindir}/sphinx-build-3

# Build libLLVM.so first.  This ensures that when libLLVM.so is linking, there
# are no other compile jobs running.  This will help reduce OOM errors on the
# builders without having to artificially limit the number of concurrent jobs.
%cmake_build --target LLVM
%cmake_build

%install
%cmake_install


%if %{without compat_build}
# Fix some man pages
mv %{buildroot}%{_mandir}/man1/tblgen.1 %{buildroot}%{_mandir}/man1/llvm-tblgen.1

# Install binaries needed for lit tests
%global test_binaries llvm-isel-fuzzer llvm-opt-fuzzer

for f in %{test_binaries}
do
    install -m 0755 %{_vpath_builddir}/bin/$f %{buildroot}%{_bindir}
done

# Remove testing of update utility tools
rm -rf test/tools/UpdateTestChecks

# Install libraries needed for unittests
%if 0%{?__isa_bits} == 64
%global build_libdir %{_vpath_builddir}/lib64
%else
%global build_libdir %{_vpath_builddir}/lib
%endif

install %{build_libdir}/libLLVMTestingSupport.a %{buildroot}%{_libdir}

%global install_srcdir %{buildroot}%{_datadir}/llvm/src
%global lit_cfg test/%{_arch}.site.cfg.py
%global lit_unit_cfg test/Unit/%{_arch}.site.cfg.py
%global lit_fedora_cfg %{_datadir}/llvm/lit.fedora.cfg.py

# Install gtest sources so clang can use them for gtest
install -d %{install_srcdir}
install -d %{install_srcdir}/utils/
cp -R utils/unittest %{install_srcdir}/utils/

# Clang needs these for running lit tests.
cp utils/update_cc_test_checks.py %{install_srcdir}/utils/
cp -R utils/UpdateTestChecks %{install_srcdir}/utils/

# One of the lit tests references this file
install -d %{install_srcdir}/docs/CommandGuide/
install -m 0644 docs/CommandGuide/dsymutil.rst %{install_srcdir}/docs/CommandGuide/

# Generate lit config files.  Strip off the last lines that initiates the
# test run, so we can customize the configuration.
head -n -2 %{_vpath_builddir}/test/lit.site.cfg.py >> %{lit_cfg}
head -n -2 %{_vpath_builddir}/test/Unit/lit.site.cfg.py >> %{lit_unit_cfg}

# Install custom fedora config file
cp %{SOURCE4} %{buildroot}%{lit_fedora_cfg}

# Patch lit config files to load custom fedora config:
for f in %{lit_cfg} %{lit_unit_cfg}; do
  echo "lit_config.load_config(config, '%{lit_fedora_cfg}')" >> $f
done

install -d %{buildroot}%{_libexecdir}/tests/llvm
install -m 0755 %{SOURCE3} %{buildroot}%{_libexecdir}/tests/llvm

# Install lit tests.  We need to put these in a tarball otherwise rpm will complain
# about some of the test inputs having the wrong object file format.
install -d %{buildroot}%{_datadir}/llvm/

# The various tar options are there to make sur the archive is the same on 32 and 64 bit arch, i.e.
# the archive creation is reproducible. Move arch-specific content out of the tarball
mv %{lit_cfg} %{install_srcdir}/%{_arch}.site.cfg.py
mv %{lit_unit_cfg} %{install_srcdir}/%{_arch}.Unit.site.cfg.py
tar --sort=name --mtime='UTC 2020-01-01' -c test/ | gzip -n > %{install_srcdir}/test.tar.gz

# Install the unit test binaries
mkdir -p %{build_llvm_libdir}
cp -R %{_vpath_builddir}/unittests %{build_llvm_libdir}/
rm -rf `find %{build_llvm_libdir} -iname 'cmake*'`

# Install libraries used for testing
install -m 0755 %{build_libdir}/BugpointPasses.so %{buildroot}%{_libdir}
install -m 0755 %{build_libdir}/LLVMHello.so %{buildroot}%{_libdir}

# Install test inputs for PDB tests
echo "%{_datadir}/llvm/src/unittests/DebugInfo/PDB" > %{build_llvm_libdir}/unittests/DebugInfo/PDB/llvm.srcdir.txt
mkdir -p %{buildroot}%{_datadir}/llvm/src/unittests/DebugInfo/PDB/
cp -R unittests/DebugInfo/PDB/Inputs %{buildroot}%{_datadir}/llvm/src/unittests/DebugInfo/PDB/

# Since the static libraries are very huge, strip them of debug symbols as well
# (Anssi 08/2012)
strip --strip-debug %{buildroot}%{_libdir}/*.a

%if %{with gold}
# Add symlink to lto plugin in the binutils plugin directory.
%{__mkdir_p} %{buildroot}%{_libdir}/bfd-plugins/
ln -s %{_libdir}/LLVMgold.so %{buildroot}%{_libdir}/bfd-plugins/
%endif

%else

# Add version suffix to binaries
mkdir -p %{buildroot}/%{_bindir}
for f in %{buildroot}/%{install_bindir}/*; do
  filename=`basename $f`
  ln -s ../../../%{install_bindir}/$filename %{buildroot}/%{_bindir}/$filename%{exec_suffix}
done

# Move header files
mkdir -p %{buildroot}/%{pkg_includedir}
ln -s ../../../%{install_includedir}/llvm %{buildroot}/%{pkg_includedir}/llvm
ln -s ../../../%{install_includedir}/llvm-c %{buildroot}/%{pkg_includedir}/llvm-c

# Fix multi-lib
mv %{buildroot}%{_bindir}/llvm-config{%{exec_suffix},%{exec_suffix}-%{__isa_bits}}
%multilib_fix_c_header --file %{install_includedir}/llvm/Config/llvm-config.h

# Create ld.so.conf.d entry
mkdir -p %{buildroot}%{_sysconfdir}/ld.so.conf.d
cat >> %{buildroot}%{_sysconfdir}/ld.so.conf.d/%{name}-%{_arch}.conf << EOF
%{pkg_libdir}
EOF

# Add version suffix to man pages and move them to mandir.
mkdir -p %{buildroot}/%{_mandir}/man1
for f in %{build_install_prefix}/share/man/man1/*; do
  filename=`basename $f | cut -f 1 -d '.'`
  mv $f %{buildroot}%{_mandir}/man1/$filename%{exec_suffix}.1
done

# Remove opt-viewer, since this is just a compatibility package.
rm -Rf %{build_install_prefix}/share/opt-viewer

%endif


%check
# TODO: Fix the failures below
LD_LIBRARY_PATH=%{buildroot}/%{_libdir}  %{__ninja} check-all -C %{_vpath_builddir} || \
%ifarch %{arm} %ix86 x86_64 aarch64
  :
%else
  false
%endif

%files
%license LICENSE.TXT
%exclude %{_mandir}/man1/llvm-config*
%{_mandir}/man1/*
%{_bindir}/*

%if %{without compat_build}
%exclude %{_bindir}/llvm-config
%exclude %{_bindir}/not
%exclude %{_bindir}/count
%exclude %{_bindir}/yaml-bench
%exclude %{_bindir}/lli-child-target
%exclude %{_bindir}/llvm-isel-fuzzer
%exclude %{_bindir}/llvm-opt-fuzzer
%{_datadir}/opt-viewer
%else
%exclude %{pkg_bindir}/llvm-config
%{pkg_bindir}
%endif

%files -n %libname
%license LICENSE.TXT
%{pkg_libdir}/libLLVM-%{maj_ver}.so
%if %{without compat_build}
%if %{with gold}
%{_libdir}/LLVMgold.so
%{_libdir}/bfd-plugins/LLVMgold.so
%endif
%{_libdir}/libLLVM-%{maj_ver}.%{min_ver}*.so
%{_libdir}/libLTO.so*
%else
%config(noreplace) %{_sysconfdir}/ld.so.conf.d/%{name}-%{_arch}.conf
%if %{with gold}
%{_libdir}/%{name}/lib/LLVMgold.so
%endif
%{pkg_libdir}/libLLVM-%{maj_ver}.%{min_ver}*.so
%{pkg_libdir}/libLTO.so*
%exclude %{pkg_libdir}/libLTO.so
%endif
%{pkg_libdir}/libRemarks.so*

%files -n %{libname_devel}
%license LICENSE.TXT
%if %{without compat_build}
%{_bindir}/llvm-config
%{_mandir}/man1/llvm-config*
%{_includedir}/llvm
%{_includedir}/llvm-c
%{_libdir}/libLLVM.so
%{_libdir}/cmake/llvm
%else
%{_bindir}/llvm-config%{exec_suffix}-%{__isa_bits}
%{pkg_bindir}/llvm-config
%{_mandir}/man1/llvm-config%{exec_suffix}.1.gz
%{install_includedir}/llvm
%{install_includedir}/llvm-c
%{pkg_includedir}/llvm
%{pkg_includedir}/llvm-c
%{pkg_libdir}/libLTO.so
%{pkg_libdir}/libLLVM.so
%{pkg_libdir}/cmake/llvm
%endif

%files doc
%license LICENSE.TXT
%doc CREDITS.TXT README.txt
%doc docs/tutorial
%doc docs/CommandGuide
%doc examples
%doc %{_pkgdocdir}/html

%files static
%license LICENSE.TXT
%if %{without compat_build}
%{_libdir}/*.a
%exclude %{_libdir}/libLLVMTestingSupport.a
%else
%{_libdir}/%{name}/lib/*.a
%endif

%if %{without compat_build}

%files test
%license LICENSE.TXT
%{_libexecdir}/tests/llvm/
%{llvm_libdir}/unittests/
%{_datadir}/llvm/src/unittests
%{_datadir}/llvm/src/test.tar.gz
%{_datadir}/llvm/src/%{_arch}.site.cfg.py
%{_datadir}/llvm/src/%{_arch}.Unit.site.cfg.py
%{_datadir}/llvm/lit.fedora.cfg.py*
%{_datadir}/llvm/src/docs/CommandGuide/dsymutil.rst
%{_bindir}/not
%{_bindir}/count
%{_bindir}/yaml-bench
%{_bindir}/lli-child-target
%{_bindir}/llvm-isel-fuzzer
%{_bindir}/llvm-opt-fuzzer
%{_libdir}/BugpointPasses.so
%{_libdir}/LLVMHello.so

%files googletest
%license LICENSE.TXT
%{_datadir}/llvm/src/utils
%{_libdir}/libLLVMTestingSupport.a

%endif


%changelog
* Thu Jan 07 2021 tv <tv> 11.0.1-4.2.mga8
+ Revision: 1669442
- LLVM 11.0.1 final

* Thu Dec 24 2020 tv <tv> 11.0.1-2.rc2.2.mga8
+ Revision: 1663455
- excludes devel deps due to plugins in library pkg

* Mon Dec 21 2020 tv <tv> 11.0.1-2.rc2.1.mga8
+ Revision: 1662556
- 11.0.1-rc2 release
- libLTO.so is now in libs package
- rename tblgen man page to match binary file
- move gold plugin into libs package
- libRemarks.so* is now in libs package

* Wed Dec 02 2020 tv <tv> 11.0.1-1.rc1.1.mga8
+ Revision: 1651658
- llvm 11.0.1-rc1
- stop targeting PowerPC, thus saving build time

* Wed Nov 25 2020 tv <tv> 11.0.0-2.1.mga8
+ Revision: 1649296
- 11.0.0
+ akien <akien>
- Update PGP key to tstellar-gpg-key.asc (used for 10.0.1 onwards)

* Thu Oct 08 2020 akien <akien> 10.0.1-1.mga8
+ Revision: 1632728
- Version 10.0.1
- Sync patches with Fedora 32
+ tv <tv>
- Make llvm-test.tar.gz creation reproducible

* Tue Jun 16 2020 ovitters <ovitters> 10.0.0-5.mga8
+ Revision: 1593527
- rebuild for new ffi

* Thu Jun 11 2020 tv <tv> 10.0.0-4.mga8
+ Revision: 1592265
- Instruct cmake not to generate RPATH

* Thu May 14 2020 tv <tv> 10.0.0-3.mga8
+ Revision: 1583685
- Install LLVMgold.so symlink in bfd-plugins directory

* Fri Apr 17 2020 tv <tv> 10.0.0-2.mga8
+ Revision: 1568340
- Remove unneeded deps on libtool & zip
- Remove unneeded deps on libstdc++
- drop old obsolete on llvm-ocaml
- Do not package UpdateTestChecks tests in llvm-tests
- Apply upstream patch bab5908df to pass gating tests

* Tue Mar 24 2020 tv <tv> 10.0.0-1.mga8
+ Revision: 1559494
- 10.0.0 final

* Tue Mar 24 2020 tv <tv> 10.0.0-0.5.3.rc5.mga8
+ Revision: 1559480
- restore excludes filters & explain it

* Sat Mar 21 2020 tv <tv> 10.0.0-0.5.2.rc5.mga8
+ Revision: 1558712
- rebuild for missing pkg on arm
- rebuild b/c of armv7 failure

* Thu Mar 19 2020 tv <tv> 10.0.0-0.5.rc5.mga8
+ Revision: 1558022
- 10.0.0 rc5

* Sun Mar 15 2020 tv <tv> 10.0.0-0.4.rc4.mga8
+ Revision: 1556556
- 10.0.0 rc4
- remove no more needed exclude filters as .so is in devel subpkg

* Thu Mar 05 2020 tv <tv> 10.0.0-0.2.rc3.mga8
+ Revision: 1554125
- 10.0.0 RC3
- Remove *_finite support (rhbz#1803203)

* Wed Feb 19 2020 tv <tv> 10.0.0-0.1.1.rc2.mga8
+ Revision: 1544028
- adjust doc subpkg filelist
- ignore testsuite failures for now
- BR zlib-devel
- restore spliting docs in doc subpkg
- enable PowerPC target (needed for testsuite)
- 10.0.0 rc2

* Wed Feb 12 2020 tv <tv> 10.0.0-0.1.1.rc1.mga8
+ Revision: 1497620
- fix test pkg deps

* Tue Feb 11 2020 tv <tv> 10.0.0-0.1.rc1.mga8
+ Revision: 1490522
- 10.0.0 rc1
+ wally <wally>
- build with new cmake macros

* Mon Oct 07 2019 tv <tv> 9.0.0-4.mga8
+ Revision: 1450204
- Build libLLVM.so first to avoid OOM errors

* Mon Sep 30 2019 tv <tv> 9.0.0-3.mga8
+ Revision: 1448366
- Remove unneeded BuildRequires: libstdc++-static-devel

* Sat Sep 21 2019 tv <tv> 9.0.0-2.mga8
+ Revision: 1444224
- re-enable testsuite
- Enable build rpath while keeping install rpath disabled
- 9.0.0 Release
- Support avr target (rhbz#1718492)

* Mon Sep 16 2019 tv <tv> 9.0.0-0.4.rc3.mga8
+ Revision: 1442223
- disable %%_python_bytecompile_extra
- 9.0.0-rc3 Release
- Split out test executables into their own export file
- Add provides for the major version of sub-packages
- Fix conflicts between llvm-static = 8 and llvm-dev < 8 around LLVMStaticExports.cmake

* Fri Apr 12 2019 tv <tv> 8.0.0-1.mga7
+ Revision: 1389465
- restrict targets (aarch64 took too much time)
- fix file list
- 8.0.0
- Fix ninja check
- Backport r351577 from trunk to fix ninja check failures
- llvm-test fixes
- Activate all backends (rhbz#1689031)
- Move some binaries to -test package, cleanup specfile

* Mon Jan 28 2019 tv <tv> 7.0.1-13.mga7
+ Revision: 1361769
- restore build_install_prefix

* Mon Jan 28 2019 tv <tv> 7.0.1-12.mga7
+ Revision: 1361636
- restore build_llvm_bindir

* Sat Jan 26 2019 kekepower <kekepower> 7.0.1-11.mga7
+ Revision: 1361070
- Fix discriminators in metadata (rhbz#1668033)
+ tv <tv>
- adjust file list

* Sat Dec 22 2018 tv <tv> 7.0.1-9.mga7
+ Revision: 1344406
- Install libraries needed for unittests

* Fri Dec 21 2018 tv <tv> 7.0.1-8.mga7
+ Revision: 1344227
- 7.0.1
- Fix running unittests as not-root user

* Fri Oct 19 2018 wally <wally> 7.0.0-8.mga7
+ Revision: 1322511
- [AArch64] DWARF: do not generate AT_location for thread local

* Wed Oct 03 2018 tv <tv> 7.mga7-current
+ Revision: 1316519
- really update run-lit-tests

* Wed Oct 03 2018 tv <tv> 7.0.0-6.mga7
+ Revision: 1316079
- Fixes for llvm-test package:
- Add some missing Requires
- Add --threads option to run-lit-tests script
- Set PATH so lit can find tools like count, not, etc.
- Don't hardcode tools directory to /usr/lib64/llvm
- Fix typo in yaml-bench define
- Only print information about failing tests

* Thu Sep 27 2018 tmb <tmb> 7.0.0-5.mga7
+ Revision: 1308155
- rebuild to restore pathfix.py fixed rpms

* Sun Sep 23 2018 tv <tv> 7.0.0-4.mga7
+ Revision: 1302178
- use newly packaged pathfix.py
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Sun Sep 23 2018 tv <tv> 7.0.0-3.mga7
+ Revision: 1296982
- Package lit tests and googletest sources
- fix install path (too much --short-circuit ruined the game)

* Sat Sep 22 2018 tv <tv> 7.0.0-2.mga7
+ Revision: 1296384
- new release

* Mon Aug 13 2018 akien <akien> 6.0.1-2.mga7
+ Revision: 1251306
- Attempt fixing underlinking issues

* Wed Jun 27 2018 tv <tv> 6.0.1-1.mga7
+ Revision: 1239966
- 6.0.1

* Fri Jun 08 2018 tv <tv> 6.0.1-0.2.rc2.mga7
+ Revision: 1235545
- 6.0.1-rc2

* Mon May 14 2018 tv <tv> 6.0.1-0.1.rc1.mga7
+ Revision: 1229589
- 6.0.1 rc1
- Re-enable arm tests that used to hang
- Fix testcase in backported patch

* Wed Mar 21 2018 tv <tv> 6.0.0-3.mga7
+ Revision: 1210937
- Prevent external projects from linking against both static and shared
  libraries (rhbz#1558657)

* Tue Mar 20 2018 tv <tv> 6.0.0-2.mga7
+ Revision: 1210770
- new release

* Mon Mar 12 2018 akien <akien> 5.0.1-2.mga7
+ Revision: 1208642
- Sync patches with f27: Thu Feb 01 2018 Tom Stellard <tstellar@redhat.com> - 5.0.1-2
  o Backport r315279 to fix an issue with rust

* Tue Dec 26 2017 tv <tv> 5.0.1-1.mga7
+ Revision: 1185118
- new release

* Tue Nov 21 2017 tv <tv> 5.0.0-4.mga7
+ Revision: 1178144
- Backport debuginfo fix for rust

* Mon Nov 06 2017 tv <tv> 5.0.0-3.mga7
+ Revision: 1176109
- use FC way in order to reduce debuginfo size for ARM

* Wed Oct 18 2017 tv <tv> 5.0.0-1.mga7
+ Revision: 1172627
- new release

* Thu Sep 21 2017 tv <tv> 4.0.1-2.mga7
+ Revision: 1156738
- new release
- drop support for mga5
- enable extra functionality when run the LLVM JIT under valgrind.

* Sat Sep 02 2017 tmb <tmb> 3.9.1-7.mga7
+ Revision: 1150672
- rebuild with new gcc/binutils

* Wed May 03 2017 akien <akien> 3.9.1-6.mga6
+ Revision: 1098886
- Add P47 and P67 backported from rust-lang fork

* Mon Mar 27 2017 tmb <tmb> 3.9.1-5.mga6
+ Revision: 1094965
- drop broken armv5tl 'buildfix'

* Mon Mar 27 2017 tmb <tmb> 3.9.1-4.mga6
+ Revision: 1094945
- rebuild with new gcc

* Sun Feb 12 2017 akien <akien> 3.9.1-3.mga6
+ Revision: 1085914
- Revert previous commit, some reverse deps like rust explicitely buildconflict llvm-static

* Fri Feb 10 2017 akien <akien> 3.9.1-2.mga6
+ Revision: 1085526
- o Rationale: https://ml.mageia.org/l/arc/dev/2017-02/msg00112.html
+ tv <tv>
- renumber patches like in FC

* Sat Jan 07 2017 ghibo <ghibo> 3.9.1-1.mga6
+ Revision: 1080449
- Update to release 3.9.1.
- Merge latest 3.9.0 Fedora patches (as well as latest patches for rust).
- Move .cmake files to %%{_libdir}/cmake/llvm/*.cmake, as upstream.
- Drop CppBackend as upstream dropped it.

* Mon Sep 05 2016 dlucio <dlucio> 3.8.1-2.mga6
+ Revision: 1050068
- update libffi BR version
- added support to allow this package to be backported

* Tue Jul 12 2016 tmb <tmb> 3.8.1-1.mga6
+ Revision: 1041233
- update to 3.8.1 (maintenance release)
+ tv <tv>
- fix color support detection on terminal

* Fri May 13 2016 tv <tv> 3.8.0-7.mga6
+ Revision: 1014737
- patch 0: fix build with latest python3-sphinx

* Mon Apr 25 2016 ngompa <ngompa> 3.8.0-6.mga6
+ Revision: 1006099
- Remove versioned libraries from -devel subpackage

* Fri Mar 25 2016 pterjan <pterjan> 3.8.0-5.mga6
+ Revision: 995390
- Do not ship ThreadPool on armv5tl, it require std::future
+ tv <tv>
- use new standard make macros
- use %%license

* Mon Mar 14 2016 tv <tv> 3.8.0-4.mga6
+ Revision: 990520
- submit to core/release

* Wed Mar 09 2016 tv <tv> 3.8.0-3.mga6
+ Revision: 988410
- 3.8.0 final

* Tue Mar 08 2016 tv <tv> 3.8.0-2.mga6
+ Revision: 987334
- clang needs LLVMHello.so
- drop unused support for builds from git & unused macro
- oops forget to reenable debug after testing local builds

* Tue Mar 08 2016 tv <tv> 3.8.0-1.mga6
+ Revision: 987327
- 3.8 RC3
- switch to cmake (losely based on FC work modulo %%cmake differences)
- clean old junk
- clang and the like are split
- split llvm-static out
- add %%check but do not run it yet

* Fri Feb 05 2016 shlomif <shlomif> 3.7.1-4.mga6
+ Revision: 939058
- Enable building LLVMgold.so for -flto/etc.

* Thu Jan 14 2016 tmb <tmb> 3.7.1-3.mga6
+ Revision: 922961
- filter out devel() provides/requires in llvm lib

* Fri Jan 08 2016 tmb <tmb> 3.7.1-2.mga6
+ Revision: 920649
- move libLLVM-<version>.so symlink from devel to main lib (mga#17415, mga#17465)

* Wed Jan 06 2016 tmb <tmb> 3.7.1-1.mga6
+ Revision: 920017
- update to 3.7.1

* Wed Dec 23 2015 tmb <tmb> 3.7.0-4.mga6
+ Revision: 913718
- rebuild with new gcc

* Sun Dec 06 2015 tmb <tmb> 3.7.0-3.mga6
+ Revision: 908619
- rebuild with gcc 5.3

* Wed Sep 23 2015 tmb <tmb> 3.7.0-2.mga6
+ Revision: 882304
- fix 32bit build
+ tv <tv>
- adjust file list
- temporary disable doc
- temporary disable man pages
- reenable doc+static_analyzer
- build fixes from FC
- disable static analyzer (needs switching to cmake)
- disable doc (needs switching to cmake)
- drop patch2 (uneeded but breaks build)
- final release
- add support for RCs
- 3.7.0rc3

* Thu Aug 20 2015 tmb <tmb> 3.6.2-5.mga6
+ Revision: 867036
- rebuild with new gcc

* Thu Aug 20 2015 tmb <tmb> 3.6.2-4.mga6
+ Revision: 866694
- rebuild with gcc 5.2.1

* Tue Aug 18 2015 tmb <tmb> 3.6.2-3.mga6
+ Revision: 865426
- rebuild with new glibc

* Sun Aug 02 2015 shlomif <shlomif> 3.6.2-2.mga6
+ Revision: 860846
- Enable RTTI.
- This is per the recommendation here: http://llvm.org/docs/Packaging.html and
  is needed by ponyc, the ponylang compiler.

* Thu Jul 30 2015 shlomif <shlomif> 3.6.2-1.mga6
+ Revision: 859054
- New version 3.6.2
- New version 3.6.1

* Fri Jun 12 2015 tmb <tmb> 3.5.2-1.mga5
+ Revision: 823009
- 3.5.2

* Wed Oct 15 2014 umeabot <umeabot> 3.5.0-3.mga5
+ Revision: 740652
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.5.0-2.mga5
+ Revision: 681969
- Mageia 5 Mass Rebuild

* Fri Sep 05 2014 tmb <tmb> 3.5.0-1.mga5
+ Revision: 672222
- update filelists
- fix build with gcc-4.9
- update to 3.5.0

* Thu Jul 31 2014 tmb <tmb> 3.4.2-2.mga5
+ Revision: 658764
- rebuild for new gcc

* Mon Jun 16 2014 tmb <tmb> 3.4.2-1.mga5
+ Revision: 637632
- add compiler-rt (mga#13141)
- llvm major is 3.4, not full version
- drop merged patches
- update to 3.4.2

* Thu May 22 2014 tmb <tmb> 3.4.1-5.mga5
+ Revision: 624841
- disable P102 and P104 tu unbreak BS, will be fixed properly for 3.4.2
- fix libclang versioning
- adjust to upstream soname breakage

* Wed May 21 2014 tmb <tmb> 3.4.1-4.mga5
+ Revision: 624783
- Teach Clang to provide ::max_align_t in C11 and C++11 modes
- Headers: Provide an ABI compatible max_align_t when _MSC_VER is defined
- Add front-end infrastructure now address space casts are in LLVM IR
- R600/SI: allow 5 more input SGPRs to a shader
- autoconf: Fix soname for libLLVM-Major.Minor.so

* Tue May 13 2014 tmb <tmb> 3.4.1-3.mga5
+ Revision: 622539
- push to release

* Sun May 11 2014 tmb <tmb> 3.4.1-2.mga5
+ Revision: 621933
- properly detect Mageia (mga#11805)

* Thu May 08 2014 tmb <tmb> 3.4.1-1.mga5
+ Revision: 621249
- update to 3.4.1

* Sun Feb 09 2014 tv <tv> 3.4-1.mga5
+ Revision: 586922
- adjust file list
- adjust file list
- rediff patch
- new release

* Sat Oct 19 2013 umeabot <umeabot> 3.3-2.mga4
+ Revision: 532640
- Mageia 4 Mass Rebuild

* Wed Aug 21 2013 tv <tv> 3.3-1.mga4
+ Revision: 469106
- adjust file list
- new release

* Sun Aug 11 2013 tmb <tmb> 3.2-8.mga4
+ Revision: 465398
- rebuild with new gcc

* Sat Aug 03 2013 tmb <tmb> 3.2-7.mga4
+ Revision: 463049
- test gcc-4.8.2 build

* Fri Aug 02 2013 shlomif <shlomif> 3.2-6.mga4
+ Revision: 462758
- Rebuild for new gcc and libstdc++.

* Thu Feb 28 2013 blino <blino> 3.2-5.mga3
+ Revision: 400669
- add a clang symlink in scan-build directory since scan-build tries to find clang relatively to its real path

* Wed Jan 16 2013 cjw <cjw> 3.2-4.mga3
+ Revision: 388816
- new snapshot from r600 branch (20130109)
  o llvm 3.2 final
  o AMDGPU target renamed to R600

* Sat Jan 12 2013 umeabot <umeabot> 3.2-3.mga3
+ Revision: 358912
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Dec 29 2012 cjw <cjw> 3.2-2.mga3
+ Revision: 336162
- 3.2 r600 branch (pre-3.2 release) for mesa 9.1pre
- patch1: from 3.2 release svn: fix build with clang 3.2
- enable both x86 and x86-64 targets on x86 and x86-64 hosts

* Mon Dec 24 2012 mitya <mitya> 3.2-1.mga3
+ Revision: 334668
- Fix build
- Cleanup, split apidocs to separate package
+ kamil <kamil>
- get rid of %%clean
- remove P1, merged upstream
- update Version and Release tago to 3.2 and 1
- new version 3.2

* Sun Oct 14 2012 ennael <ennael> 3.1-8.mga3
+ Revision: 305457
- Documentation group

* Mon Sep 24 2012 mitya <mitya> 3.1-7.mga3
+ Revision: 296968
- Rebuild for GCC 4.7.2

* Thu Sep 06 2012 anssi <anssi> 3.1-6.mga3
+ Revision: 288912
- do not create shared library development symlinks for libclang*.a at all
  since libclang.so only exports a limited set of symbols

* Thu Sep 06 2012 anssi <anssi> 3.1-5.mga3
+ Revision: 288885
- clang-devel: do not create shared library symlinks for those static
  libraries that are actually not included in libclang.so, to fix undefined
  symbol errors when compiling against those (reported by Joseph Wang)
- include libclangTooling.a in libclang.so (shared-tooling.patch from
  upstream)

* Thu Aug 30 2012 fwang <fwang> 3.1-4.mga3
+ Revision: 285683
- promote correct libdir

* Mon Aug 06 2012 luigiwalser <luigiwalser> 3.1-3.mga3
+ Revision: 278987
- rebuild for libffi

* Fri Aug 03 2012 blino <blino> 3.1-2.mga3
+ Revision: 278253
- require llvm in devel package (for tools like llvm-tblgen)

* Thu Aug 02 2012 anssi <anssi> 3.1-1.mga3
+ Revision: 277999
- new version 3.1
- drop llvm-soname.patch, fixed upstream
- re-enable clang
- replace the use of %%exclude with explicit file lists

* Thu Aug 02 2012 anssi <anssi> 3.0-9.mga3
+ Revision: 277981
- fix libification of libllvm3.0 by moving unversioned libraries to the
  devel package
- libify libclang and versionize the shared library
- drop llvm-config patch for dynamic linking, and instead provide
  .so symlinks that match the .a names so that shared linking will
  be enabled with the regular "llvm-config --libs" output
- move clang development libraries to libified clang-devel package
- force build with g++ and gcc instead of buildconflicts
- strip debug symbols from static libraries to make the llvm-devel
  package approx. 30 times smaller
- in preparation of 3.1 release which will be immediately released
  after this package release (the main purpose of this intermediate
  release is to provide a properly libified libllvm3.0):
  o drop gold LTO link patch, fixed upstream in 3.1
  o temporarily disable clang
+ blino <blino>
- buildconflict with clang < 3.1 since it would fail to build with gcc 4.7 headers

* Wed Jun 27 2012 fwang <fwang> 3.0-8.mga3
+ Revision: 264273
- rebuild for new gcc

* Thu Apr 12 2012 blino <blino> 3.0-7.mga2
+ Revision: 230547
- move libLLVM.so in devel package

* Thu Apr 12 2012 blino <blino> 3.0-6.mga2
+ Revision: 230524
- llvm-devel should require the library package

* Thu Apr 12 2012 fwang <fwang> 3.0-5.mga2
+ Revision: 230344
- add conflicts so that it upgrades correctly

* Thu Apr 12 2012 blino <blino> 3.0-4.mga2
+ Revision: 230340
- split out static libs, headers and config binary in a devel package
- do not package LLVMHello.so (taken from Fedora)
- move sub-libs in library package (but exclude big clang)

* Wed Apr 11 2012 blino <blino> 3.0-3.mga2
+ Revision: 230271
- add clang and enable it by default (most spec bits are copied from Fedora)
+ fwang <fwang>
- add upstream patch to fix gold link

* Mon Dec 05 2011 fwang <fwang> 3.0-1.mga2
+ Revision: 176830
- update file list
- update file list
- Copy missing file into the expected location
- new version 3.0

* Wed Nov 09 2011 anssi <anssi> 2.9-2.mga2
+ Revision: 165987
- split libLLVM shared library to a library package, allowing
  e.g. DRI drivers to link to it instead of using static linking
- make "llvm-config --libs" print the shared library instead of
  static libraries (config-shared.patch)
- add soname to libLLVM (soname.patch)
- versionize obsoletes
- move the libLLVM shared library to a standard path
- build with libffi support
- build with PIC enabled on all platforms
- drop wrong rpaths from binaries
- add development symlink for the libLLVM shared library
- fix typo in obsoletes

* Wed Jun 22 2011 fwang <fwang> 2.9-1.mga2
+ Revision: 111941
- new version 2.9

* Fri Feb 11 2011 ahmad <ahmad> 2.8-4.mga1
+ Revision: 50381
- imported package llvm

